@@ -390,12 +390,12 @@ class ScenarioHandler:
         events_to_process = summarise_results.get_events_to_process(self.yearly_events)
         all_events = summarise_results.process_all_events_results(events_to_process)
 
-        all_events = summarise_results.join_ewr_parameters(cols_to_add=['multigauge'],
+        all_events = summarise_results.join_ewr_parameters(cols_to_add=['Multigauge'],
                         left_table=all_events,
                         left_on=['gauge','pu','ewr'],
                         selected_columns= ['scenario', 'gauge', 'pu', 'ewr', 'waterYear', 'startDate', 'endDate',
                                 'eventDuration', 'eventLength', 
-                                'multigauge'],
+                                'Multigauge'],
                         parameter_sheet_path=self.parameter_sheet)
 
         return all_events
@@ -408,14 +408,14 @@ class ScenarioHandler:
         to_process = summarise_results.pu_dfs_to_process(self.pu_ewr_statistics)
         yearly_ewr_results = summarise_results.process_df_results(to_process)
 
-        yearly_ewr_results = summarise_results.join_ewr_parameters(cols_to_add=['multigauge'],
+        yearly_ewr_results = summarise_results.join_ewr_parameters(cols_to_add=['Multigauge'],
                                 left_table=yearly_ewr_results,
                                 left_on=['gauge','pu','ewrCode'],
                                 selected_columns= ['Year', 'eventYears', 'numAchieved', 'numEvents', 'numEventsAll', 'maxInterEventDays',
                                             'maxInterEventDaysAchieved', 'eventLength', 'eventLengthAchieved', 'totalEventDays', 'totalEventDaysAchieved',
                                             'maxEventDays', 'maxRollingEvents', 'maxRollingAchievement',
                                             'daysBetweenEvents', 'missingDays', 'totalPossibleDays', 'ewrCode',
-                                            'scenario', 'gauge', 'pu', 'multigauge'],
+                                            'scenario', 'gauge', 'pu', 'Multigauge'],
                                 parameter_sheet_path=self.parameter_sheet)
                                 
         return yearly_ewr_results
